#ifndef DEPRECATED_HEADER_QtNfc_qnfcglobal_h
#define DEPRECATED_HEADER_QtNfc_qnfcglobal_h
#if defined(__GNUC__)
#  warning Header <QtNfc/qnfcglobal.h> is deprecated. Please include <QtNfc/qtnfcglobal.h> instead.
#elif defined(_MSC_VER)
#  pragma message ("Header <QtNfc/qnfcglobal.h> is deprecated. Please include <QtNfc/qtnfcglobal.h> instead.")
#endif
#include <QtNfc/qtnfcglobal.h>
#if 0
#pragma qt_no_master_include
#endif
#endif
